#' @keywords internal
#' @aliases permChacko-package
#' @importFrom methods is
"_PACKAGE"
